@@ -8,7 +8,7 @@ from cms.api import Page
 from cms.extensions.extension_pool import extension_pool
 from cms.models.pluginmodel import CMSPlugin
 
-from ...core.models import BasePageExtension, PagePluginMixin
+from ...core.models import BasePageExtension
 from ..defaults import PROGRAMS_PAGE
 
 
@@ -27,12 +27,12 @@ class Program(BasePageExtension):
 
     def __str__(self):
         """Human representation of a program"""
-        return "{model}: {name}".format(
-            model=self._meta.verbose_name.title(), name=self.extended_object.get_title()
-        )
+        model = self._meta.verbose_name.title()
+        name = self.extended_object.get_title()
+        return f"{model:s}: {name:s}"
 
 
-class ProgramPluginModel(PagePluginMixin, CMSPlugin):
+class ProgramPluginModel(CMSPlugin):
     """
     Program plugin model handles the relation between the ProgramPluginModel
     and its program instance
@@ -50,5 +50,9 @@ class ProgramPluginModel(PagePluginMixin, CMSPlugin):
         verbose_name = _("program plugin")
         verbose_name_plural = _("program plugins")
 
+    def __str__(self):
+        """Human representation of a page plugin"""
+        return self.page.get_title()
+
 
 extension_pool.register(Program)
