@@ -27,6 +27,10 @@ class ArrayField(forms.Field):
         was passed to us by the consumer
         """
         if value:
+            # Support comma-separated lists in addition to the traditional repeated-key format
+            # for query string parameters containing lists.
+            if isinstance(value, list) and len(value) == 1 and "," in value[0]:
+                value = value[0].split(",")
             # We have something to check: attempt to iterate over it
             try:
                 for base_type_value in value:
@@ -35,10 +39,10 @@ class ArrayField(forms.Field):
                     self.base_type.clean(base_type_value) for base_type_value in value
                 ]
             # Iteration over subvalues failed, the value was invalid
-            except TypeError:
+            except TypeError as error:
                 raise ValidationError(
                     "Failed to iterate over value, got a non-iterable type."
-                )
+                ) from error
         # We're missing a required value
         elif self.required:
             raise ValidationError("Missing required value.")
