@@ -6,13 +6,18 @@ from functools import reduce
 from django import forms
 from django.conf import settings
 from django.utils.translation import get_language
+from django.utils.translation import gettext_lazy as _
 
 import arrow
 
 from richie.apps.courses.models import CourseState
 
 from .defaults import QUERY_ANALYZERS, RELATED_CONTENT_BOOST
-from .filter_definitions import FILTERS, AvailabilityFilterDefinition
+from .filter_definitions import (
+    FILTERS,
+    AvailabilityFilterDefinition,
+    BaseFilterDefinition,
+)
 
 # Instantiate filter fields for each filter defined in settings
 # It is of the form:
@@ -21,8 +26,12 @@ from .filter_definitions import FILTERS, AvailabilityFilterDefinition
 #             ArrayField(required=False, base_type=forms.CharField(max_length=50)),
 #             True,
 #         ),
-#         subjects_include: (
-#             CharField(required=False, max_length=20),
+#         subjects_aggs: (
+#             ArrayField(required=False, base_type=forms.CharField(max_length=50)),
+#             True,
+#         ),
+#         subjects_children_aggs: (
+#             forms.CharField(required=False, max_length=50),
 #             False,
 #         ),
 #         languages: (
@@ -58,6 +67,15 @@ class CourseSearchForm(SearchForm):
     definitions and generate Elasticsearch queries.
     """
 
+    facet_sorting = forms.ChoiceField(
+        required=False,
+        choices=[
+            (BaseFilterDefinition.SORTING_CONF, _("Sort by configuration")),
+            (BaseFilterDefinition.SORTING_COUNT, _("Sort by facet count")),
+            (BaseFilterDefinition.SORTING_NAME, _("Sort alphabetically")),
+        ],
+    )
+
     def __init__(self, *args, data=None, **kwargs):
         """
         Adapt the search form to handle filters:
