@@ -12,11 +12,18 @@ from django.utils import translation
 from cms.models import Title
 from djangocms_picture.models import Picture
 
+from richie.apps.search.indexers.organizations import OrganizationsIndexer
 from richie.plugins.plain_text.models import PlainText
 from richie.plugins.simple_picture.helpers import get_picture_info
 from richie.plugins.simple_text_ckeditor.models import SimpleText
 
-from ...courses.models import MAX_DATE, CategoryPluginModel, Course, CourseState
+from ...courses.models import (
+    MAX_DATE,
+    CategoryPluginModel,
+    Course,
+    CourseRunCatalogVisibility,
+    CourseState,
+)
 from ..defaults import ES_INDICES_PREFIX, ES_STATE_WEIGHTS
 from ..forms import CourseSearchForm
 from ..text_indexing import MULTILINGUAL_TEXT
@@ -202,18 +209,24 @@ class CoursesIndexer:
             "absolute_url": {"type": "object", "enabled": False},
             "cover_image": {"type": "object", "enabled": False},
             "icon": {"type": "object", "enabled": False},
+            "organization_highlighted_cover_image": {
+                "type": "object",
+                "enabled": False,
+            },
         },
     }
     display_fields = [
         "absolute_url",
         "categories",
         "code",
+        "course_runs",
         "cover_image",
         "duration",
         "effort",
         "icon",
         "introduction",
         "organization_highlighted",
+        "organization_highlighted_cover_image",
         "organizations",
         "title",
     ]
@@ -282,15 +295,19 @@ class CoursesIndexer:
             "script": {
                 "lang": "painless",
                 "source": BEST_STATE_SCRIPT
+                # pylint: disable-next=consider-using-f-string
                 + """
                 if (best_state == 0) {{
                     // The course is on-going and open
                     // Ordered by ascending end of enrollment datetime. The next course to
                     // end enrollment is displayed first.
                     return (_score + 1) * (
-                        {weight_0:d} * params.ms_since_epoch - ZonedDateTime.parse(
-                            params._source.course_runs[best_index]['enrollment_end'], formatter
-                        ).toInstant().toEpochMilli()
+                        {weight_0:d} * params.ms_since_epoch + Math.max(
+                            0,
+                            2 * params.ms_since_epoch - ZonedDateTime.parse(
+                                params._source.course_runs[best_index]['enrollment_end'], formatter
+                            ).toInstant().toEpochMilli()
+                        )
                     );
                 }}
                 else if (best_state == 1) {{
@@ -298,9 +315,12 @@ class CoursesIndexer:
                     // Ordered by starting datetime. The next course to start is displayed
                     // first.
                     return (_score + 1) * (
-                        {weight_1:d} * params.ms_since_epoch - ZonedDateTime.parse(
-                            params._source.course_runs[best_index]['start'], formatter
-                        ).toInstant().toEpochMilli()
+                        {weight_1:d} * params.ms_since_epoch + Math.max(
+                            0,
+                            2 * params.ms_since_epoch - ZonedDateTime.parse(
+                                params._source.course_runs[best_index]['start'], formatter
+                            ).toInstant().toEpochMilli()
+                        )
                     );
                 }}
                 else if (best_state == 2) {{
@@ -308,9 +328,12 @@ class CoursesIndexer:
                     // Ordered by ascending end of enrollment datetime. The next course to
                     // end enrollment is displayed first.
                     return (_score + 1) * (
-                        {weight_2:d} * params.ms_since_epoch - ZonedDateTime.parse(
-                            params._source.course_runs[best_index]['enrollment_end'], formatter
-                        ).toInstant().toEpochMilli()
+                        {weight_2:d} * params.ms_since_epoch + Math.max(
+                            0,
+                            2 * params.ms_since_epoch - ZonedDateTime.parse(
+                                params._source.course_runs[best_index]['enrollment_end'], formatter
+                            ).toInstant().toEpochMilli()
+                        )
                     );
                 }}
                 else if (best_state == 3) {{
@@ -318,27 +341,36 @@ class CoursesIndexer:
                     // Ordered by starting datetime. The next course to start is displayed
                     // first.
                     return (_score + 1) * (
-                        {weight_3:d} * params.ms_since_epoch - ZonedDateTime.parse(
-                            params._source.course_runs[best_index]['start'], formatter
-                        ).toInstant().toEpochMilli()
+                        {weight_3:d} * params.ms_since_epoch + Math.max(
+                            0,
+                            2 * params.ms_since_epoch - ZonedDateTime.parse(
+                                params._source.course_runs[best_index]['start'], formatter
+                            ).toInstant().toEpochMilli()
+                        )
                     );
                 }}
                 else if (best_state == 4) {{
                     // The course is future but already closed for enrollment
                     // Ordered by end datetime. The next course to end is displayed first
                     return (_score + 1) * (
-                        {weight_4:d} * params.ms_since_epoch - ZonedDateTime.parse(
-                            params._source.course_runs[best_index]['start'], formatter
-                        ).toInstant().toEpochMilli()
+                        {weight_4:d} * params.ms_since_epoch + Math.max(
+                            0,
+                            2 * params.ms_since_epoch - ZonedDateTime.parse(
+                                params._source.course_runs[best_index]['start'], formatter
+                            ).toInstant().toEpochMilli()
+                        )
                     );
                 }}
                 else if (best_state == 5) {{
                     // The course is on-going and closed for enrollment
                     // Ordered by end datetime. The next course to end is displayed first
                     return (_score + 1) * (
-                        {weight_5:d} * params.ms_since_epoch - ZonedDateTime.parse(
-                            params._source.course_runs[best_index]['end'], formatter
-                        ).toInstant().toEpochMilli()
+                        {weight_5:d} * params.ms_since_epoch + Math.max(
+                            0,
+                            2 * params.ms_since_epoch - ZonedDateTime.parse(
+                                params._source.course_runs[best_index]['end'], formatter
+                            ).toInstant().toEpochMilli()
+                        )
                     );
                 }}
                 else if (best_state == 6) {{
@@ -353,7 +385,7 @@ class CoursesIndexer:
                 }}
                 // The course has no course runs
                 return 0;
-                """.format(  # pylint: disable=consider-using-f-string
+                """.format(
                     **{
                         f"weight_{i:d}": weight
                         for i, weight in enumerate(ES_STATE_WEIGHTS)
@@ -502,7 +534,6 @@ class CoursesIndexer:
         # in the same query
         category_pages = (
             course.get_root_to_leaf_public_category_pages()
-            .select_related("node")
             .prefetch_related(
                 Prefetch(
                     "title_set",
@@ -510,7 +541,6 @@ class CoursesIndexer:
                     queryset=Title.objects.filter(published=True),
                 )
             )
-            .only("node", "pk")
             .distinct()
         )
 
@@ -525,13 +555,17 @@ class CoursesIndexer:
                     queryset=Title.objects.filter(published=True),
                 )
             )
-            .only("extended_object__node")
             .distinct()
         )
         organization_main = course.get_main_organization()
         organization_highlighted = (
             organizations.get(id=organization_main.id) if organization_main else None
         )
+        organization_highlighted_cover_image = (
+            OrganizationsIndexer.get_logo_images(organization_main)
+            if organization_main
+            else {}
+        )
 
         # Prepare persons, making sure we get title information for persons
         # in the same query
@@ -561,14 +595,16 @@ class CoursesIndexer:
                 "languages": cr["languages"],
             }
             for cr in course.course_runs.filter(
-                start__isnull=False, enrollment_start__isnull=False
+                start__isnull=False,
+                enrollment_start__isnull=False,
+                catalog_visibility=CourseRunCatalogVisibility.COURSE_AND_SEARCH,
             )
             .order_by("-end")
             .values("start", "end", "enrollment_start", "enrollment_end", "languages")
         ]
 
         return {
-            "_id": str(course.extended_object_id),
+            "_id": course.get_es_id(),
             "_index": index,
             "_op_type": action,
             "absolute_url": {
@@ -611,11 +647,12 @@ class CoursesIndexer:
             # Pick the highlighted organization from the organizations QuerySet to benefit from
             # the prefetch of related title sets
             "organization_highlighted": {
-                title.language: title.title
+                title.language: title.menu_title if title.menu_title else title.title
                 for title in organization_highlighted.extended_object.published_titles
             }
             if organization_highlighted
             else None,
+            "organization_highlighted_cover_image": organization_highlighted_cover_image,
             "organizations": [
                 organization.get_es_id() for organization in organizations
             ],
@@ -634,9 +671,7 @@ class CoursesIndexer:
                 ],
                 {},
             ),
-            "persons": [
-                str(person.public_extension.extended_object_id) for person in persons
-            ],
+            "persons": [person.get_es_id() for person in persons],
             "persons_names": reduce(
                 lambda acc, title: {
                     **acc,
@@ -704,11 +739,17 @@ class CoursesIndexer:
             "id": es_course["_id"],
             "categories": source["categories"],
             "code": source["code"],
+            "course_runs": source["course_runs"],
             "organization_highlighted": get_best_field_language(
                 source["organization_highlighted"], language
             )
             if source.get("organization_highlighted", None)
             else None,
+            "organization_highlighted_cover_image": get_best_field_language(
+                source["organization_highlighted_cover_image"], language
+            )
+            if source.get("organization_highlighted_cover_image", None)
+            else None,
             "organizations": source["organizations"],
             "state": CourseState(**state),
         }
